@@ -48,6 +48,9 @@ extern "C"
     XLAPI         double XLAPIENTRY xlSheetColWidthW(SheetHandle handle, int col);
     XLAPI         double XLAPIENTRY xlSheetRowHeightW(SheetHandle handle, int row);
 
+    XLAPI            int XLAPIENTRY xlSheetColWidthPxW(SheetHandle handle, int col);
+    XLAPI            int XLAPIENTRY xlSheetRowHeightPxW(SheetHandle handle, int row);
+
     XLAPI            int XLAPIENTRY xlSheetSetColW(SheetHandle handle, int colFirst, int colLast, double width, FormatHandle format, int hidden);
     XLAPI            int XLAPIENTRY xlSheetSetRowW(SheetHandle handle, int row, double height, FormatHandle format, int hidden);
 
@@ -214,6 +217,20 @@ extern "C"
 
     XLAPI            int XLAPIENTRY xlSheetAddIgnoredErrorW(SheetHandle handle, int rowFirst, int colFirst, int rowLast, int colLast, int iError);
 
+    XLAPI           void XLAPIENTRY xlSheetAddDataValidationW(SheetHandle handle, int type, int op, int rowFirst, int rowLast, int colFirst, int colLast, const wchar_t* value1, const wchar_t* value2);
+
+    XLAPI           void XLAPIENTRY xlSheetAddDataValidationExW(SheetHandle handle, int type, int op, int rowFirst, int rowLast, int colFirst, int colLast, const wchar_t* value1, const wchar_t* value2,
+                                                               int allowBlank, int hideDropDown, int showInputMessage, int showErrorMessage, const wchar_t* promptTitle, const wchar_t* prompt,
+                                                               const wchar_t* errorTitle, const wchar_t* error, int errorStyle);
+
+    XLAPI           void XLAPIENTRY xlSheetAddDataValidationDoubleW(SheetHandle handle, int type, int op, int rowFirst, int rowLast, int colFirst, int colLast, double value1, double value2);
+
+    XLAPI           void XLAPIENTRY xlSheetAddDataValidationDoubleExW(SheetHandle handle, int type, int op, int rowFirst, int rowLast, int colFirst, int colLast, double value1, double value2,
+                                                               int allowBlank, int hideDropDown, int showInputMessage, int showErrorMessage, const wchar_t* promptTitle, const wchar_t* prompt,
+                                                               const wchar_t* errorTitle, const wchar_t* error, int errorStyle);
+
+    XLAPI           void XLAPIENTRY xlSheetRemoveDataValidationsW(SheetHandle handle);
+
 #ifdef __cplusplus
 }
 #endif
